@@ -52,9 +52,9 @@ class Sublist(list):
         temp = list(i for i in range(0, len(self)) if self[i] == other)
 
         if len(temp) == 1:
-            return temp[0]
-        else:
-            return temp
+            temp = temp[0]
+
+        return temp
 
     def __gt__(self,
                other):
@@ -65,9 +65,9 @@ class Sublist(list):
         temp = list(i for i in range(0, len(self)) if self[i] > other)
 
         if len(temp) == 1:
-            return temp[0]
-        else:
-            return temp
+            temp = temp[0]
+
+        return temp
 
     def __ge__(self,
                other):
@@ -78,9 +78,9 @@ class Sublist(list):
         temp = list(i for i in range(0, len(self)) if self[i] >= other)
 
         if len(temp) == 1:
-            return temp[0]
-        else:
-            return temp
+            temp = temp[0]
+
+        return temp
 
     def __lt__(self,
                other):
@@ -91,9 +91,9 @@ class Sublist(list):
         temp = list(i for i in range(0, len(self)) if self[i] < other)
 
         if len(temp) == 1:
-            return temp[0]
-        else:
-            return temp
+            temp = temp[0]
+
+        return temp
 
     def __le__(self,
                other):
@@ -104,9 +104,9 @@ class Sublist(list):
         temp = list(i for i in range(0, len(self)) if self[i] <= other)
 
         if len(temp) == 1:
-            return temp[0]
-        else:
-            return temp
+            temp = temp[0]
+
+        return temp
 
     def __ne__(self,
                other):
@@ -117,9 +117,9 @@ class Sublist(list):
         temp = list(i for i in range(0, len(self)) if self[i] != other)
 
         if len(temp) == 1:
-            return temp[0]
-        else:
-            return temp
+            temp = temp[0]
+
+        return temp
 
     def __add__(self,
                 other):
@@ -170,9 +170,9 @@ class Sublist(list):
         :return: List
         """
         if index:
-            return [i for i, x in enumerate(self) if llim <= x <= ulim]
+            return list(i for i, x in enumerate(self) if llim <= x <= ulim)
         else:
-            return [x for x in self if llim <= x <= ulim]
+            return list(x for x in self if llim <= x <= ulim)
 
     def add(self,
             elem):
@@ -294,10 +294,7 @@ class Sublist(list):
         if step is not None:
             if start % step > 0:
                 out.append(start)
-                if start < step:
-                    start = step
-                elif start > step:
-                    start = start + step - (start % step)
+                start = step * (start < step) + (start + step - (start % step)) * (start > step)
             iterator = range(start, end, step)
         else:
             step = 1
@@ -639,26 +636,25 @@ class Sublist(list):
         Method to reduce a 2D or 3D array using a specific method
         :param array: Numpy array
         :param method: Method to use for reduction (options: mean, median, std_dev,
-                                                        percentile_xx, min, max, default:mean
+                                                        pctl_xx, min, max, default:mean
                                                              here xx is the percentile)
         :param axis: Axis to apply the reducer along
         :return: float
         """
-        if method == 'mean':
-            return np.mean(array, axis=axis)
-        elif method == 'median':
-            return np.median(array, axis=axis)
-        elif method == 'std_dev':
-            return np.std(array, axis=axis)
-        if method == 'min':
-            return np.min(array, axis=axis)
-        if method == 'max':
-            return np.max(array, axis=axis)
-        elif 'percentile' in method:
-            perc = int(method.split('_')[1])
-            return np.percentile(array, perc, axis=axis)
+
+        methods = {'mean': np.mean,
+                   'median': np.median,
+                   'std_dev': np.std,
+                   'min': np.min,
+                   'max': np.max,
+                   'pctl': np.percentile}
+
+        if 'pctl' in method:
+            return methods['pctl'](array, int(method.split('_')[1]), axis=axis)
+        elif method in ('mean', 'median', 'std_dev', 'min', 'max'):
+            return methods[method](array, axis=axis)
         else:
-            raise ValueError("Reducer = {} is not implemented".format(method))
+            raise RuntimeError("Reducer {} is not implemented".format(method))
 
 
 class Handler(object):
@@ -701,9 +697,6 @@ class Handler(object):
         """
         if not os.path.exists(self.dirname):
             os.makedirs(self.dirname)
-            # print('Created path: ' + input_di
-        else:
-            pass  # print('Path already exists: ' + self.dirname)
 
     def add_to_filename(self,
                         string=None,
@@ -715,7 +708,7 @@ class Handler(object):
                           This can be used in addition to the string
         :return:
         """
-        components = self.basename.split('.')
+
         if timestamp:
             timestamp = datetime.datetime.now().isoformat().replace('-', '').replace(':', '').split('.')[0]
         else:
@@ -726,11 +719,16 @@ class Handler(object):
         else:
             string = timestamp
 
-        if len(components) >= 2:
-            return self.dirname + self.sep + '.'.join(components[0:-1]) + \
-                      string + '.' + str(components[-1])
+        file_name, file_ext = os.path.splitext(self.basename)
+
+        file_name += string
+
+        self.basename = file_name + file_ext
+
+        if self.dirname is not None:
+            return self.dirname + self.sep + self.basename
         else:
-            return self.basename + self.sep + components[0] + string
+            return self.basename
 
     def file_rename_check(self):
         """
@@ -966,24 +964,23 @@ class Handler(object):
 
         getcontext().prec = precision
 
-        if unit == 'bit':
-            output = float(Decimal(size)*Decimal(2**3))
-        elif unit == 'kb':
-            output = float(Decimal(size)/Decimal(2**10))
-        elif unit == 'mb':
-            output = float(Decimal(size)/(Decimal(2**20)))
-        elif unit == 'gb':
-            output = float(Decimal(size)/(Decimal(2**30)))
-        elif unit == 'tb':
-            output = float(Decimal(size)/(Decimal(2**40)))
-        elif unit == 'pb':
-            output = float(Decimal(size)/(Decimal(2**50)))
-        else:
-            output = size
+        if unit not in ('b', 'kb', 'mb', 'gb', 'tb', 'pb', 'bit'):
+            raise NotImplementedError('Unrecognized size unit')
+
+        output = (unit == 'bit') * float(Decimal(size)*Decimal(2**3)) + \
+                 (unit == 'b') * float(Decimal(size)) + \
+                 (unit == 'kb') * float(Decimal(size)/Decimal(2**10)) + \
+                 (unit == 'mb') * float(Decimal(size)/(Decimal(2**20))) + \
+                 (unit == 'gb') * float(Decimal(size)/(Decimal(2**30))) + \
+                 (unit == 'tb') * float(Decimal(size)/(Decimal(2**40))) + \
+                 (unit == 'pb') * float(Decimal(size)/(Decimal(2**50)))
+
+        output = round(output, precision)
+
         if as_long:
-            return int(round(output, precision))
-        else:
-            return round(output, precision)
+            output = int(output)
+
+        return output
 
     def write_list_to_file(self,
                            input_list,
@@ -1072,35 +1069,25 @@ class Handler(object):
             'date': 'date',
             'array_echo': 'echo "Job ID is"$SLURM_ARRAY_TASK_ID'
         }
+
+        script_list = [script_dict['bash'],
+                       script_dict['job-name'],
+                       script_dict['time'],
+                       script_dict['cpus'],
+                       script_dict['mem'],
+                       script_dict['ntasks']]
+
         if array:
-            script_list = [
-                script_dict['bash'],
-                script_dict['job-name'],
-                script_dict['time'],
-                script_dict['cpus'],
-                script_dict['mem'],
-                script_dict['partition'],
-                script_dict['array_def'],
-                script_dict['array_out'],
-                script_dict['date'],
-            ]
-            for key, value in kwargs.items():
-                script_list.append(value)
-            script_list.append(script_dict['date'])
-        else:
-            script_list = [
-                script_dict['bash'],
-                script_dict['job-name'],
-                script_dict['time'],
-                script_dict['cpus'],
-                script_dict['mem'],
-                script_dict['partition'],
-                script_dict['out'],
-                script_dict['date'],
-            ]
-            for key, value in kwargs.items():
-                script_list.append(value)
-            script_list.append(script_dict['date'])
+            script_list += [script_dict['array_def'],
+                            script_dict['array_out'],
+                            script_dict['array_echo']]
+
+        script_list.append(script_dict['date'])
+
+        for key, value in kwargs.items():
+            script_list.append(value)
+
+        script_list.append(script_dict['date'])
 
         self.write_list_to_file(script_list)
 
@@ -1285,9 +1272,14 @@ class Handler(object):
             lines.append(delimiter.join(list(str(val) for _, val in data_dict.items())))
 
         if append:
-            with open(outfile, 'a') as f:
-                for line in lines:
-                    f.write(line + '\n')
+            if os.path.isfile(outfile):
+                with open(outfile, 'a') as f:
+                    for line in lines:
+                        f.write(line + '\n')
+            else:
+                with open(outfile, 'w') as f:
+                    for line in lines:
+                        f.write(line + '\n')
         else:
             with open(outfile, 'w') as f:
                 for line in lines:
@@ -1629,6 +1621,22 @@ class Timer:
         """
         return '<Timer class for {}>'.format(self.func.__name__)
 
+    def __call__(self, *args, **kwargs):
+        """
+        Function to compute timing for input function
+        :return: Function and prints time taken
+        """
+
+        t1 = time.time()
+        val = self.func(*args, **kwargs)
+        t2 = time.time()
+
+        # time to run
+        t = self.display_time(t2 - t1)
+
+        sys.stdout.write("Time it took to run {}: {}\n".format(self.func.__name__, t))
+        return val
+
     @staticmethod
     def display_time(seconds,
                      precision=3):
@@ -1677,40 +1685,31 @@ class Timer:
         # join output
         return ' '.join(result)
 
-    @classmethod
-    def timing(cls,
-               doit=False):
+    @staticmethod
+    def timing(func):
         """
         Function to compute timing for input function
-        :param doit: (abbr: Do it.) Keyword to determine if the wrapper returns
-                     the function with or without timing it
         :return: Function and prints time taken
         """
 
-        def time_it(func):
-
+        @wraps(func)
+        def wrapper(*args, **kwargs):
             """
-            Executes wrapper
+            Wrapper for func
+            :param args: Arguments
+            :param kwargs: Key word arguments
+            :return: Function func return
             """
-            @wraps(func)
-            def wrapper(*args, **kwargs):
-                """
-                Wrapper for func
-                :param args: Arguments
-                :param kwargs: Key word arguments
-                :return: Function func return
-                """
-                if doit:
-                    t1 = time.time()
-                    val = func(*args, **kwargs)
-                    t2 = time.time()
 
-                    # time to run
-                    t = Timer.display_time(t2 - t1)
+            t1 = time.time()
+            val = func(*args, **kwargs)
+            t2 = time.time()
+
+            # time to run
+            t = Timer.display_time(t2 - t1)
+
+            sys.stdout.write("Time it took to run {}: {}\n".format(func.__name__, t))
+            return val
+
+        return wrapper
 
-                    sys.stdout.write("Time it took to run {}: {}\n".format(func.__name__, t))
-                    return val
-                else:
-                    return func(*args, **kwargs)
-            return wrapper
-        return time_it
