@@ -1078,6 +1078,7 @@ class Raster(object):
         if len(bands) == 1:
             temp_band = self.datasource.GetRasterBand(bands[0])
             tile_arr = temp_band.ReadAsArray(*new_block_coords)
+            tile_arr = tile_arr[np.newaxis, :, :]
 
         else:
             tile_arr = np.zeros((len(bands),
@@ -1801,15 +1802,6 @@ class MultiRaster:
         vrt_dict['separate'] = True
         vrt_dict['hideNodata'] = False
 
-        vrt_dict['creationOptions'] = []
-
-        if 'compress' in kwargs:
-            vrt_dict['creationOptions'].append('COMPRESS={}'.format(str(kwargs['compress']).upper()))
-
-        if 'bigtiff' in kwargs:
-            vrt_dict['creationOptions'].append('BIGTIFF={}'.format(str(kwargs['bigtiff']).upper()))
-
-
         if verbose:
             Opt.cprint('Files: \n{}'.format('\n'.join(list(self.filelist[i] for i in order))))
 
@@ -1819,15 +1811,30 @@ class MultiRaster:
             vrtfile = Handler(self.filelist[0]).dirname + Handler().sep + 'layerstack1.vrt'
             outfile = Handler(self.filelist[0]).dirname + Handler().sep + 'layerstack1.tif'
         else:
-            vrtfile = outfile.split('.tif')[0] + '.vrt'
+            vrtfile = outfile.replace('.tif', '.vrt')
 
-        _vrt_ = gdal.BuildVRT(vrtfile, list(self.filelist[i] for i in order), options=_vrt_opt_)
+        _vrt_ = gdal.BuildVRT(vrtfile,
+                              list(self.filelist[i] for i in order),
+                              options=_vrt_opt_)
 
         if not return_vrt:
+
+            vrt_dict['creationOptions'] = []
+
+            if 'compress' in kwargs:
+                vrt_dict['creationOptions'].append('COMPRESS={}'.format(str(kwargs['compress']).upper()))
+
+            if 'bigtiff' in kwargs:
+                vrt_dict['creationOptions'].append('BIGTIFF={}'.format(str(kwargs['bigtiff']).upper()))
+
             if verbose:
                 Opt.cprint('Writing layer stack file : {} ...'.format(outfile))
 
-            gdal.Translate(outfile, _vrt_, **kwargs)
+            trns_opts = gdal.TranslateOptions(**vrt_dict)
+
+            gdal.Translate(outfile,
+                           _vrt_,
+                           options=trns_opts)
             _vrt_ = None
 
             if verbose:
